
#ifndef VTKACCELERATORSVTKMCORE_EXPORT_H
#define VTKACCELERATORSVTKMCORE_EXPORT_H

#ifdef VTKACCELERATORSVTKMCORE_STATIC_DEFINE
#  define VTKACCELERATORSVTKMCORE_EXPORT
#  define VTKACCELERATORSVTKMCORE_NO_EXPORT
#else
#  ifndef VTKACCELERATORSVTKMCORE_EXPORT
#    ifdef AcceleratorsVTKmCore_EXPORTS
        /* We are building this library */
#      define VTKACCELERATORSVTKMCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKACCELERATORSVTKMCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKACCELERATORSVTKMCORE_NO_EXPORT
#    define VTKACCELERATORSVTKMCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKACCELERATORSVTKMCORE_DEPRECATED
#  define VTKACCELERATORSVTKMCORE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKACCELERATORSVTKMCORE_DEPRECATED_EXPORT
#  define VTKACCELERATORSVTKMCORE_DEPRECATED_EXPORT VTKACCELERATORSVTKMCORE_EXPORT VTKACCELERATORSVTKMCORE_DEPRECATED
#endif

#ifndef VTKACCELERATORSVTKMCORE_DEPRECATED_NO_EXPORT
#  define VTKACCELERATORSVTKMCORE_DEPRECATED_NO_EXPORT VTKACCELERATORSVTKMCORE_NO_EXPORT VTKACCELERATORSVTKMCORE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKACCELERATORSVTKMCORE_NO_DEPRECATED
#    define VTKACCELERATORSVTKMCORE_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkAcceleratorsVTKmCoreModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKACCELERATORSVTKMCORE_EXPORT_H */
